summaryrefslogtreecommitdiffstats
path: root/lib/Service/FolderServiceV2.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/Service/FolderServiceV2.php')
-rw-r--r--lib/Service/FolderServiceV2.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/Service/FolderServiceV2.php b/lib/Service/FolderServiceV2.php
index 17d955876..1e710a37b 100644
--- a/lib/Service/FolderServiceV2.php
+++ b/lib/Service/FolderServiceV2.php
@@ -184,17 +184,17 @@ class FolderServiceV2 extends Service
*
* @param string $userId Folder owner
* @param int $id Folder ID
* @param int|null $maxItemID Highest item ID to mark as read
*
* @return int
*
* @throws ServiceConflictException
* @throws ServiceNotFoundException
*/
- public function read(string $userId, int $id, ?int $maxItemID = null): int
+ public function read(string $userId, int $id, ?int $newestItemId = null): int
{
$folder = $this->find($userId, $id);
- return $this->mapper->read($userId, $folder->getId(), $maxItemID);
+ return $this->mapper->read($userId, $folder->getId(), $newestItemId);
}
}
@@ -184,17 +184,17 @@ class FolderServiceV2 extends Service
* @param string $userId Folder owner
* @param int $id Folder ID
- * @param int|null $maxItemID Highest item ID to mark as read
+ * @param int|null $newestItemId Highest item ID to mark as read
*
* @return int